@@ -21,12 +21,15 @@ class FlagX(Transform):
 
     def __init__(
         self,
-        name: str,
         enum: Type[IntFlag],
         nbytes: int,
         byteorder: ByteOrderHint = "little",
+        name: Optional[str] = None,
     ) -> None:
-        super().__init__(name)
+        if name is None:
+            name = f"{enum.__name__} (IntFlag)"
+
+        super().__init__(name, hint=enum.__name__)
 
         assert nbytes > 0
         assert byteorder in {"big", "little"}
