@@ -293,17 +293,7 @@ class Member(property):
         if self.fmt_is_a_factory:
             store.cls_name = f"{name}_fmt"
         else:
-            for cls_name in [self.fmt.name, self.fmt.__hint__]:
-                try:
-                    is_same = code_injector.f_globals[cls_name] is self.fmt
-                except KeyError:  # NameError:
-                    pass
-                else:
-                    if is_same:
-                        store.cls_name = cls_name
-                        break
-            else:
-                store.cls_name = f"cls.{name}.fmt"
+            store.cls_name = f"cls.{name}.fmt"
 
         store.local_name = "m_" + name
         store.type_hint = code_injector.get_type_hint_expression(name)
