@@ -4,8 +4,10 @@
 """Sample BitFields data store class."""
 
 from enum import IntEnum
+from typing import Union
 
 from plum.bitfields import bitfield, BitFields
+from plum.enum import EnumX
 
 
 class Register(IntEnum):
@@ -25,4 +27,4 @@ class MyBits(BitFields, nbytes=2, default=0x0):
     f1: int = bitfield(lsb=0, size=8, default=0xAB)
     f2: Register = bitfield(lsb=8, size=4, typ=Register)
     f3: bool = bitfield(lsb=12, size=1, typ=bool)
-    f4: bool = bitfield(lsb=13, size=1, typ=bool)
+    f4: Union[int, Register] = bitfield(lsb=13, size=2, typ=EnumX(Register))
