@@ -21,36 +21,36 @@ class TestConformance(Case):
         bindata=b"\x00\x12",
         nbytes=2,
         values=(
-            MyBits(f1=0, f2=Register.R0, f3=True, f4=False),
+            MyBits(f1=0, f2=Register.R0, f3=True, f4=Register.PC),
             0x1200,
-            dict(f1=0, f2=Register.R0, f3=True, f4=False),
+            dict(f1=0, f2=Register.R0, f3=True, f4=Register.PC),
         ),
         dump=Baseline(
             """
-            +---------+--------+-------------+-------------------+--------------------+
-            | Offset  | Access | Value       | Bytes             | Format             |
-            +---------+--------+-------------+-------------------+--------------------+
-            | 0       |        | 4608        | 00 12             | MyBits (BitFields) |
-            |  [0:8]  | f1     | 0           | ........ 00000000 | int                |
-            |  [8:12] | f2     | Register.R0 | ....0010 ........ | Register           |
-            |  [12]   | f3     | True        | ...1.... ........ | bool               |
-            |  [13]   | f4     | False       | ..0..... ........ | bool               |
-            +---------+--------+-------------+-------------------+--------------------+
+            +----------+--------+-------------+-------------------+--------------------+
+            | Offset   | Access | Value       | Bytes             | Format             |
+            +----------+--------+-------------+-------------------+--------------------+
+            | 0        |        | 4608        | 00 12             | MyBits (BitFields) |
+            |  [0:8]   | f1     | 0           | ........ 00000000 | int                |
+            |  [8:12]  | f2     | Register.R0 | ....0010 ........ | Register           |
+            |  [12]    | f3     | True        | ...1.... ........ | bool               |
+            |  [13:15] | f4     | Register.PC | .00..... ........ | Register (IntEnum) |
+            +----------+--------+-------------+-------------------+--------------------+
             """
         ),
         excess=Baseline(
             """
-            +---------+--------+----------------+-------------------+--------------------+
-            | Offset  | Access | Value          | Bytes             | Format             |
-            +---------+--------+----------------+-------------------+--------------------+
-            | 0       |        | 4608           | 00 12             | MyBits (BitFields) |
-            |  [0:8]  | f1     | 0              | ........ 00000000 | int                |
-            |  [8:12] | f2     | Register.R0    | ....0010 ........ | Register           |
-            |  [12]   | f3     | True           | ...1.... ........ | bool               |
-            |  [13]   | f4     | False          | ..0..... ........ | bool               |
-            +---------+--------+----------------+-------------------+--------------------+
-            | 2       |        | <excess bytes> | 99                |                    |
-            +---------+--------+----------------+-------------------+--------------------+
+            +----------+--------+----------------+-------------------+--------------------+
+            | Offset   | Access | Value          | Bytes             | Format             |
+            +----------+--------+----------------+-------------------+--------------------+
+            | 0        |        | 4608           | 00 12             | MyBits (BitFields) |
+            |  [0:8]   | f1     | 0              | ........ 00000000 | int                |
+            |  [8:12]  | f2     | Register.R0    | ....0010 ........ | Register           |
+            |  [12]    | f3     | True           | ...1.... ........ | bool               |
+            |  [13:15] | f4     | Register.PC    | .00..... ........ | Register (IntEnum) |
+            +----------+--------+----------------+-------------------+--------------------+
+            | 2        |        | <excess bytes> | 99                |                    |
+            +----------+--------+----------------+-------------------+--------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -73,7 +73,7 @@ class TestConformance(Case):
         ),
         implementation=Baseline(
             """
-            def __init__(self, *, f1: int = 171, f2: Union[int, Register], f3: Union[int, bool], f4: Union[int, bool]) -> None:
+            def __init__(self, *, f1: int = 171, f2: 'Register', f3: bool, f4: Union[int, 'Register']) -> None:
                 self.__value__ = 171
                 self.f1 = f1
                 self.f2 = f2
@@ -92,12 +92,12 @@ class TestConformance(Case):
                 self.__value__ = (self.__value__ & -256) | (value & 255)
 
             @f2.getter
-            def f2(self) -> Register:
-                return Register((int(self) >> 8) & 15)
+            def f2(self, _typ=f2.typ) -> 'Register':
+                return _typ((int(self) >> 8) & 15)
 
             @f2.setter
-            def f2(self, value: Union[int, Register]) -> None:
-                value = int(Register(value))
+            def f2(self, value: 'Register', _typ=f2.typ) -> None:
+                value = int(_typ(value))
                 self.__value__ = (self.__value__ & -3841) | ((value & 15) << 8)
 
             @f3.getter
@@ -105,18 +105,20 @@ class TestConformance(Case):
                 return bool((int(self) >> 12) & 1)
 
             @f3.setter
-            def f3(self, value: Union[int, bool]) -> None:
+            def f3(self, value: bool) -> None:
                 value = int(bool(value))
                 self.__value__ = (self.__value__ & -4097) | ((value & 1) << 12)
 
             @f4.getter
-            def f4(self) -> bool:
-                return bool((int(self) >> 13) & 1)
+            def f4(self, _typ=f4.typ) -> Union[int, 'Register']:
+                return _typ((int(self) >> 13) & 3)
 
             @f4.setter
-            def f4(self, value: Union[int, bool]) -> None:
-                value = int(bool(value))
-                self.__value__ = (self.__value__ & -8193) | ((value & 1) << 13)
+            def f4(self, value: Union[int, 'Register'], _typ=f4.typ) -> None:
+                value = int(_typ(value))
+                if not (0 <= value <= 3):
+                    raise ValueError("bit field 'f4' requires 0 <= number <= 3")
+                self.__value__ = (self.__value__ & -24577) | ((value & 3) << 13)
 
             def __repr__(self) -> str:
                 try:
