@@ -9,7 +9,7 @@ from plum.bytes import BytesX
 from plum.conformance import wrap_message
 from plum.exceptions import PackError
 
-bytes4 = BytesX("bytes4", nbytes=4)
+bytes4 = BytesX(name="bytes4", nbytes=4)
 
 
 class Test:
