@@ -10,7 +10,7 @@ class TestDefault:
 
     """Test with as many left to default as possible."""
 
-    bytesx = BytesX("bytesx", nbytes=4)
+    bytesx = BytesX(name="bytesx", nbytes=4)
 
     def test_name(self):
         assert self.bytesx.name == "bytesx"
@@ -26,10 +26,13 @@ class TestPositional:
 
     """Test explicitly defined with positional argument."""
 
-    bytesx = BytesX("bytesx", 4, b"\x99")
+    bytesx = BytesX(4, b"\x99", "name")
+
+    def test_hint(self):
+        assert self.bytesx.__hint__ == "bytes"
 
     def test_name(self):
-        assert self.bytesx.name == "bytesx"
+        assert self.bytesx.name == "name"
 
     def test_nbytes(self):
         assert self.bytesx.nbytes == 4
@@ -42,4 +45,21 @@ class TestKeyword(TestPositional):
 
     """Test explicitly defined with keyword argument."""
 
-    bytesx = BytesX(name="bytesx", nbytes=4, pad=b"\x99")
+    bytesx = BytesX(nbytes=4, pad=b"\x99", name="name")
+
+
+class TestDefaultNameHint:
+    def test_greedy(self):
+        xform = BytesX()
+        assert xform.__hint__ == "bytes"
+        assert xform.name == "bytes (greedy)"
+
+    def test_fixed(self):
+        xform = BytesX(nbytes=4)
+        assert xform.__hint__ == "bytes"
+        assert xform.name == "bytes (fixed)"
+
+    def test_padded(self):
+        xform = BytesX(nbytes=4, pad=b" ")
+        assert xform.__hint__ == "bytes"
+        assert xform.name == "bytes (fixed,padded)"
