@@ -7,7 +7,7 @@ from plum.dump import Dump
 from plum.bytes import BytesX
 
 
-greedy_bytes = BytesX("greedy_bytes")
+greedy_bytes = BytesX(name="greedy_bytes")
 
 
 class TestUnpack:
