@@ -12,10 +12,13 @@ class TestDefault:
 
     """Test with as many left to default as possible."""
 
-    register = FlagX("register", Register, 1)
+    register = FlagX(enum=Register, nbytes=1)
+
+    def test_hint(self):
+        assert self.register.__hint__ == "Register"
 
     def test_name(self):
-        assert self.register.name == "register"
+        assert self.register.name == "Register (IntFlag)"
 
     def test_enum(self):
         assert self.register.enum is Register
@@ -31,10 +34,13 @@ class TestPositional:
 
     """Test explicitly defined with positional argument."""
 
-    register = FlagX("register", Register, 2, "big")
+    register = FlagX(Register, 2, "big", "name")
+
+    def test_hint(self):
+        assert self.register.__hint__ == "Register"
 
     def test_name(self):
-        assert self.register.name == "register"
+        assert self.register.name == "name"
 
     def test_enum(self):
         assert self.register.enum is Register
@@ -50,4 +56,4 @@ class TestKeyword(TestPositional):
 
     """Test explicitly defined with keyword argument."""
 
-    register = FlagX(name="register", enum=Register, nbytes=2, byteorder="big")
+    register = FlagX(enum=Register, nbytes=2, byteorder="big", name="name")
