@@ -12,7 +12,7 @@ from plum.none import NoneX
 class Test(Case):
 
     data = CaseData(
-        fmt=NoneX("none"),
+        fmt=NoneX(name="none"),
         bindata=b"",
         nbytes=0,
         values=(None,),
