@@ -92,7 +92,7 @@ class TestFirst(Case):
         ),
         implementation=Baseline(
             """
-            def __init__(self, *, m1: Pet, m2: int = 1, m3: int = 2, m4: int = 255) -> None:
+            def __init__(self, *, m1: 'Pet', m2: int = m2.default, m3: int = m3.default, m4: int = m4.default) -> None:
                 if not 0 <= m1 <= 15:
                    raise ValueError("'m1' out of range, 0 <= m1 <= 15")
 
@@ -105,12 +105,12 @@ class TestFirst(Case):
                 self[:] = (m1, m2, m3, m4)
 
             @m1.getter
-            def m1(self) -> Pet:
+            def m1(self) -> 'Pet':
                 return self[0]
 
             @m1.setter
-            def m1(self, value: Pet) -> None:
-                self[0] = Pet(value)
+            def m1(self, value: 'Pet') -> None:
+                self[0] = type(self).m1.typ(value)
 
             @m2.getter
             def m2(self) -> int:
@@ -158,13 +158,13 @@ class TestFirst(Case):
 
                     pieces.append(bitfields_0.to_bytes(2, "little", signed=False))
 
-                    uint8.__pack__(m_m4, pieces, dump)
+                    cls.m4.fmt.__pack__(m_m4, pieces, dump)
 
                 else:
                     bitfields_0_dump = dump.add_record()
                     bitfields_0 = 0
 
-                    dump.add_record(access="m1", bits=(0, 4), value=m_m1, fmt=Pet)
+                    dump.add_record(access="m1", bits=(0, 4), value=m_m1, fmt=cls.m1.typ)
                     bitfields_0 |= (bitfields_0 & -16) | (m_m1 & 0xf)
 
                     dump.add_record(access="m2", bits=(4, 4), value=m_m2, fmt=int)
@@ -177,8 +177,8 @@ class TestFirst(Case):
                     bitfields_0_dump.value = str(bitfields_0)
                     bitfields_0_dump.memory = pieces[-1]
 
-                    m4_dump = dump.add_record(access="m4", fmt=uint8)
-                    uint8.__pack__(m_m4, pieces, m4_dump)
+                    m4_dump = dump.add_record(access="m4", fmt=cls.m4.fmt)
+                    cls.m4.fmt.__pack__(m_m4, pieces, m4_dump)
 
             @classmethod
             def __unpack__(cls, buffer: bytes, offset: int, dump: Optional[Record] = None) -> Tuple["MyStruct", int]:
@@ -188,21 +188,21 @@ class TestFirst(Case):
                     bitfields_0, offset = cls.m1.__unpack__(buffer, offset, dump, "little", nbytes=2, signed=False)
 
                     m_m1 = (bitfields_0 >> 0) & 0xf
-                    m_m1 = Pet(m_m1)
+                    m_m1 = cls.m1.typ(m_m1)
 
                     m_m2 = (bitfields_0 >> 4) & 0xf
 
                     m_m3 = (bitfields_0 >> 8) & 0xff
 
-                    m_m4, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_m4, offset = cls.m4.fmt.__unpack__(buffer, offset, dump)
 
                 else:
                     bitfields_0_dump = dump.add_record()
                     bitfields_0, offset = cls.m1.__unpack__(buffer, offset, bitfields_0_dump, "little", nbytes=2, signed=False)
 
                     m_m1 = (bitfields_0 >> 0) & 0xf
-                    m_m1 = Pet(m_m1)
-                    dump.add_record(access="m1", bits=(0, 4), value=m_m1, fmt=Pet)
+                    m_m1 = cls.m1.typ(m_m1)
+                    dump.add_record(access="m1", bits=(0, 4), value=m_m1, fmt=cls.m1.typ)
 
                     m_m2 = (bitfields_0 >> 4) & 0xf
                     dump.add_record(access="m2", bits=(4, 4), value=m_m2, fmt=int)
@@ -210,8 +210,8 @@ class TestFirst(Case):
                     m_m3 = (bitfields_0 >> 8) & 0xff
                     dump.add_record(access="m3", bits=(8, 8), value=m_m3, fmt=int)
 
-                    m4_dump = dump.add_record(access="m4", fmt=uint8)
-                    m_m4, offset = uint8.__unpack__(buffer, offset, m4_dump)
+                    m4_dump = dump.add_record(access="m4", fmt=cls.m4.fmt)
+                    m_m4, offset = cls.m4.fmt.__unpack__(buffer, offset, m4_dump)
 
                 structure[:] = (m_m1, m_m2, m_m3, m_m4)
 
@@ -304,7 +304,7 @@ class TestLast(Case):
         ),
         implementation=Baseline(
             """
-            def __init__(self, *, m0: int = 255, m1: int, m2: int = 1, m3: int = 2) -> None:
+            def __init__(self, *, m0: int = m0.default, m1: int, m2: int = m2.default, m3: int = m3.default) -> None:
                 if not 0 <= m1 <= 15:
                    raise ValueError("'m1' out of range, 0 <= m1 <= 15")
 
@@ -362,7 +362,7 @@ class TestLast(Case):
                 (m_m0, m_m1, m_m2, m_m3) = value
 
                 if dump is None:
-                    uint8.__pack__(m_m0, pieces, dump)
+                    cls.m0.fmt.__pack__(m_m0, pieces, dump)
 
                     bitfields_0 = 0
 
@@ -375,8 +375,8 @@ class TestLast(Case):
                     pieces.append(bitfields_0.to_bytes(2, "little", signed=False))
 
                 else:
-                    m0_dump = dump.add_record(access="m0", fmt=uint8)
-                    uint8.__pack__(m_m0, pieces, m0_dump)
+                    m0_dump = dump.add_record(access="m0", fmt=cls.m0.fmt)
+                    cls.m0.fmt.__pack__(m_m0, pieces, m0_dump)
 
                     bitfields_0_dump = dump.add_record()
                     bitfields_0 = 0
@@ -399,7 +399,7 @@ class TestLast(Case):
                 structure = list.__new__(cls)
 
                 if dump is None:
-                    m_m0, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_m0, offset = cls.m0.fmt.__unpack__(buffer, offset, dump)
 
                     bitfields_0, offset = cls.m1.__unpack__(buffer, offset, dump, "little", nbytes=2, signed=False)
 
@@ -410,8 +410,8 @@ class TestLast(Case):
                     m_m3 = (bitfields_0 >> 8) & 0xff
 
                 else:
-                    m0_dump = dump.add_record(access="m0", fmt=uint8)
-                    m_m0, offset = uint8.__unpack__(buffer, offset, m0_dump)
+                    m0_dump = dump.add_record(access="m0", fmt=cls.m0.fmt)
+                    m_m0, offset = cls.m0.fmt.__unpack__(buffer, offset, m0_dump)
 
                     bitfields_0_dump = dump.add_record()
                     bitfields_0, offset = cls.m1.__unpack__(buffer, offset, bitfields_0_dump, "little", nbytes=2, signed=False)
@@ -661,7 +661,7 @@ class TestMultiple(Case):
 
                     pieces.append(bitfields_0.to_bytes(2, "little", signed=False))
 
-                    uint8.__pack__(m_m2, pieces, dump)
+                    cls.m2.fmt.__pack__(m_m2, pieces, dump)
 
                     bitfields_1 = 0
 
@@ -671,7 +671,7 @@ class TestMultiple(Case):
 
                     pieces.append(bitfields_1.to_bytes(1, "little", signed=False))
 
-                    uint8.__pack__(m_m5, pieces, dump)
+                    cls.m5.fmt.__pack__(m_m5, pieces, dump)
 
                     bitfields_2 = 0
 
@@ -695,8 +695,8 @@ class TestMultiple(Case):
                     bitfields_0_dump.value = str(bitfields_0)
                     bitfields_0_dump.memory = pieces[-1]
 
-                    m2_dump = dump.add_record(access="m2", fmt=uint8)
-                    uint8.__pack__(m_m2, pieces, m2_dump)
+                    m2_dump = dump.add_record(access="m2", fmt=cls.m2.fmt)
+                    cls.m2.fmt.__pack__(m_m2, pieces, m2_dump)
 
                     bitfields_1_dump = dump.add_record()
                     bitfields_1 = 0
@@ -711,8 +711,8 @@ class TestMultiple(Case):
                     bitfields_1_dump.value = str(bitfields_1)
                     bitfields_1_dump.memory = pieces[-1]
 
-                    m5_dump = dump.add_record(access="m5", fmt=uint8)
-                    uint8.__pack__(m_m5, pieces, m5_dump)
+                    m5_dump = dump.add_record(access="m5", fmt=cls.m5.fmt)
+                    cls.m5.fmt.__pack__(m_m5, pieces, m5_dump)
 
                     bitfields_2_dump = dump.add_record()
                     bitfields_2 = 0
@@ -738,7 +738,7 @@ class TestMultiple(Case):
 
                     m_m1 = (bitfields_0 >> 4) & 0xff
 
-                    m_m2, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_m2, offset = cls.m2.fmt.__unpack__(buffer, offset, dump)
 
                     bitfields_1, offset = cls.m3.__unpack__(buffer, offset, dump, "little", nbytes=1, signed=False)
 
@@ -746,7 +746,7 @@ class TestMultiple(Case):
 
                     m_m4 = (bitfields_1 >> 4) & 0xf
 
-                    m_m5, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_m5, offset = cls.m5.fmt.__unpack__(buffer, offset, dump)
 
                     bitfields_2, offset = cls.m6.__unpack__(buffer, offset, dump, "little", nbytes=2, signed=False)
 
@@ -764,8 +764,8 @@ class TestMultiple(Case):
                     m_m1 = (bitfields_0 >> 4) & 0xff
                     dump.add_record(access="m1", bits=(4, 8), value=m_m1, fmt=int)
 
-                    m2_dump = dump.add_record(access="m2", fmt=uint8)
-                    m_m2, offset = uint8.__unpack__(buffer, offset, m2_dump)
+                    m2_dump = dump.add_record(access="m2", fmt=cls.m2.fmt)
+                    m_m2, offset = cls.m2.fmt.__unpack__(buffer, offset, m2_dump)
 
                     bitfields_1_dump = dump.add_record()
                     bitfields_1, offset = cls.m3.__unpack__(buffer, offset, bitfields_1_dump, "little", nbytes=1, signed=False)
@@ -776,8 +776,8 @@ class TestMultiple(Case):
                     m_m4 = (bitfields_1 >> 4) & 0xf
                     dump.add_record(access="m4", bits=(4, 4), value=m_m4, fmt=int)
 
-                    m5_dump = dump.add_record(access="m5", fmt=uint8)
-                    m_m5, offset = uint8.__unpack__(buffer, offset, m5_dump)
+                    m5_dump = dump.add_record(access="m5", fmt=cls.m5.fmt)
+                    m_m5, offset = cls.m5.fmt.__unpack__(buffer, offset, m5_dump)
 
                     bitfields_2_dump = dump.add_record()
                     bitfields_2, offset = cls.m6.__unpack__(buffer, offset, bitfields_2_dump, "little", nbytes=2, signed=False)
