@@ -164,42 +164,42 @@ class TestSimpleSingleDim(Case):
                 (m_data_len, m_data, m_bookend) = value
 
                 if dump is None:
-                    uint8.__pack__(m_data_len, pieces, dump)
+                    cls.data_len.fmt.__pack__(m_data_len, pieces, dump)
 
-                    uint8array.__pack__(m_data, pieces, dump, dims=(m_data_len, ))
+                    cls.data.fmt.__pack__(m_data, pieces, dump, dims=(m_data_len, ))
 
-                    uint8.__pack__(m_bookend, pieces, dump)
+                    cls.bookend.fmt.__pack__(m_bookend, pieces, dump)
 
                 else:
-                    data_len_dump = dump.add_record(access="data_len", fmt=uint8)
-                    uint8.__pack__(m_data_len, pieces, data_len_dump)
+                    data_len_dump = dump.add_record(access="data_len", fmt=cls.data_len.fmt)
+                    cls.data_len.fmt.__pack__(m_data_len, pieces, data_len_dump)
 
-                    data_dump = dump.add_record(access="data", fmt=uint8array)
-                    uint8array.__pack__(m_data, pieces, data_dump, dims=(m_data_len, ))
+                    data_dump = dump.add_record(access="data", fmt=cls.data.fmt)
+                    cls.data.fmt.__pack__(m_data, pieces, data_dump, dims=(m_data_len, ))
 
-                    bookend_dump = dump.add_record(access="bookend", fmt=uint8)
-                    uint8.__pack__(m_bookend, pieces, bookend_dump)
+                    bookend_dump = dump.add_record(access="bookend", fmt=cls.bookend.fmt)
+                    cls.bookend.fmt.__pack__(m_bookend, pieces, bookend_dump)
 
             @classmethod
             def __unpack__(cls, buffer: bytes, offset: int, dump: Optional[Record] = None) -> Tuple["SampleStruct", int]:
                 structure = list.__new__(cls)
 
                 if dump is None:
-                    m_data_len, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_data_len, offset = cls.data_len.fmt.__unpack__(buffer, offset, dump)
 
-                    m_data, offset = uint8array.__unpack__(buffer, offset, dump, dims=(m_data_len, ))
+                    m_data, offset = cls.data.fmt.__unpack__(buffer, offset, dump, dims=(m_data_len, ))
 
-                    m_bookend, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_bookend, offset = cls.bookend.fmt.__unpack__(buffer, offset, dump)
 
                 else:
-                    data_len_dump = dump.add_record(access="data_len", fmt=uint8)
-                    m_data_len, offset = uint8.__unpack__(buffer, offset, data_len_dump)
+                    data_len_dump = dump.add_record(access="data_len", fmt=cls.data_len.fmt)
+                    m_data_len, offset = cls.data_len.fmt.__unpack__(buffer, offset, data_len_dump)
 
-                    data_dump = dump.add_record(access="data", fmt=uint8array)
-                    m_data, offset = uint8array.__unpack__(buffer, offset, data_dump, dims=(m_data_len, ))
+                    data_dump = dump.add_record(access="data", fmt=cls.data.fmt)
+                    m_data, offset = cls.data.fmt.__unpack__(buffer, offset, data_dump, dims=(m_data_len, ))
 
-                    bookend_dump = dump.add_record(access="bookend", fmt=uint8)
-                    m_bookend, offset = uint8.__unpack__(buffer, offset, bookend_dump)
+                    bookend_dump = dump.add_record(access="bookend", fmt=cls.bookend.fmt)
+                    m_bookend, offset = cls.bookend.fmt.__unpack__(buffer, offset, bookend_dump)
 
                 structure[:] = (m_data_len, m_data, m_bookend)
 
@@ -361,28 +361,28 @@ class TestTypeFactorySingleDim(Case):
                 (m_data_type, m_data_len, m_data, m_bookend) = value
 
                 if dump is None:
-                    datatype.__pack__(m_data_type, pieces, dump)
+                    cls.data_type.fmt.__pack__(m_data_type, pieces, dump)
 
-                    uint8.__pack__(m_data_len, pieces, dump)
+                    cls.data_len.fmt.__pack__(m_data_len, pieces, dump)
 
                     data_fmt = cls.data.fmt(value)
                     data_fmt.__pack__(m_data, pieces, dump, dims=(m_data_len, ))
 
-                    uint8.__pack__(m_bookend, pieces, dump)
+                    cls.bookend.fmt.__pack__(m_bookend, pieces, dump)
 
                 else:
-                    data_type_dump = dump.add_record(access="data_type", fmt=datatype)
-                    datatype.__pack__(m_data_type, pieces, data_type_dump)
+                    data_type_dump = dump.add_record(access="data_type", fmt=cls.data_type.fmt)
+                    cls.data_type.fmt.__pack__(m_data_type, pieces, data_type_dump)
 
-                    data_len_dump = dump.add_record(access="data_len", fmt=uint8)
-                    uint8.__pack__(m_data_len, pieces, data_len_dump)
+                    data_len_dump = dump.add_record(access="data_len", fmt=cls.data_len.fmt)
+                    cls.data_len.fmt.__pack__(m_data_len, pieces, data_len_dump)
 
                     data_fmt = cls.data.fmt(value)
                     data_dump = dump.add_record(access="data", fmt=data_fmt)
                     data_fmt.__pack__(m_data, pieces, data_dump, dims=(m_data_len, ))
 
-                    bookend_dump = dump.add_record(access="bookend", fmt=uint8)
-                    uint8.__pack__(m_bookend, pieces, bookend_dump)
+                    bookend_dump = dump.add_record(access="bookend", fmt=cls.bookend.fmt)
+                    cls.bookend.fmt.__pack__(m_bookend, pieces, bookend_dump)
 
             @classmethod
             def __unpack__(cls, buffer: bytes, offset: int, dump: Optional[Record] = None) -> Tuple["SampleStruct", int]:
@@ -390,26 +390,26 @@ class TestTypeFactorySingleDim(Case):
                 add_member = structure.append
 
                 if dump is None:
-                    m_data_type, offset = datatype.__unpack__(buffer, offset, dump)
+                    m_data_type, offset = cls.data_type.fmt.__unpack__(buffer, offset, dump)
                     add_member(m_data_type)
 
-                    m_data_len, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_data_len, offset = cls.data_len.fmt.__unpack__(buffer, offset, dump)
                     add_member(m_data_len)
 
                     data_fmt = cls.data.fmt(structure)
                     m_data, offset = data_fmt.__unpack__(buffer, offset, dump, dims=(m_data_len, ))
                     add_member(m_data)
 
-                    m_bookend, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_bookend, offset = cls.bookend.fmt.__unpack__(buffer, offset, dump)
                     add_member(m_bookend)
 
                 else:
-                    data_type_dump = dump.add_record(access="data_type", fmt=datatype)
-                    m_data_type, offset = datatype.__unpack__(buffer, offset, data_type_dump)
+                    data_type_dump = dump.add_record(access="data_type", fmt=cls.data_type.fmt)
+                    m_data_type, offset = cls.data_type.fmt.__unpack__(buffer, offset, data_type_dump)
                     add_member(m_data_type)
 
-                    data_len_dump = dump.add_record(access="data_len", fmt=uint8)
-                    m_data_len, offset = uint8.__unpack__(buffer, offset, data_len_dump)
+                    data_len_dump = dump.add_record(access="data_len", fmt=cls.data_len.fmt)
+                    m_data_len, offset = cls.data_len.fmt.__unpack__(buffer, offset, data_len_dump)
                     add_member(m_data_len)
 
                     data_fmt = cls.data.fmt(structure)
@@ -417,8 +417,8 @@ class TestTypeFactorySingleDim(Case):
                     m_data, offset = data_fmt.__unpack__(buffer, offset, data_dump, dims=(m_data_len, ))
                     add_member(m_data)
 
-                    bookend_dump = dump.add_record(access="bookend", fmt=uint8)
-                    m_bookend, offset = uint8.__unpack__(buffer, offset, bookend_dump)
+                    bookend_dump = dump.add_record(access="bookend", fmt=cls.bookend.fmt)
+                    m_bookend, offset = cls.bookend.fmt.__unpack__(buffer, offset, bookend_dump)
                     add_member(m_bookend)
 
                 return structure, offset
@@ -614,18 +614,18 @@ class TestTypeFactoryMultiDim(Case):
                 (m_data_type, m_data_dims, m_data, m_bookend) = value
 
                 if dump is None:
-                    datatype.__pack__(m_data_type, pieces, dump)
+                    cls.data_type.fmt.__pack__(m_data_type, pieces, dump)
 
                     cls.data_dims.fmt.__pack__(m_data_dims, pieces, dump)
 
                     data_fmt = cls.data.fmt(value)
                     data_fmt.__pack__(m_data, pieces, dump, dims=m_data_dims)
 
-                    uint8.__pack__(m_bookend, pieces, dump)
+                    cls.bookend.fmt.__pack__(m_bookend, pieces, dump)
 
                 else:
-                    data_type_dump = dump.add_record(access="data_type", fmt=datatype)
-                    datatype.__pack__(m_data_type, pieces, data_type_dump)
+                    data_type_dump = dump.add_record(access="data_type", fmt=cls.data_type.fmt)
+                    cls.data_type.fmt.__pack__(m_data_type, pieces, data_type_dump)
 
                     data_dims_dump = dump.add_record(access="data_dims", fmt=cls.data_dims.fmt)
                     cls.data_dims.fmt.__pack__(m_data_dims, pieces, data_dims_dump)
@@ -634,8 +634,8 @@ class TestTypeFactoryMultiDim(Case):
                     data_dump = dump.add_record(access="data", fmt=data_fmt)
                     data_fmt.__pack__(m_data, pieces, data_dump, dims=m_data_dims)
 
-                    bookend_dump = dump.add_record(access="bookend", fmt=uint8)
-                    uint8.__pack__(m_bookend, pieces, bookend_dump)
+                    bookend_dump = dump.add_record(access="bookend", fmt=cls.bookend.fmt)
+                    cls.bookend.fmt.__pack__(m_bookend, pieces, bookend_dump)
 
             @classmethod
             def __unpack__(cls, buffer: bytes, offset: int, dump: Optional[Record] = None) -> Tuple["MultiDimStruct", int]:
@@ -643,7 +643,7 @@ class TestTypeFactoryMultiDim(Case):
                 add_member = structure.append
 
                 if dump is None:
-                    m_data_type, offset = datatype.__unpack__(buffer, offset, dump)
+                    m_data_type, offset = cls.data_type.fmt.__unpack__(buffer, offset, dump)
                     add_member(m_data_type)
 
                     m_data_dims, offset = cls.data_dims.fmt.__unpack__(buffer, offset, dump)
@@ -653,12 +653,12 @@ class TestTypeFactoryMultiDim(Case):
                     m_data, offset = data_fmt.__unpack__(buffer, offset, dump, dims=m_data_dims)
                     add_member(m_data)
 
-                    m_bookend, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_bookend, offset = cls.bookend.fmt.__unpack__(buffer, offset, dump)
                     add_member(m_bookend)
 
                 else:
-                    data_type_dump = dump.add_record(access="data_type", fmt=datatype)
-                    m_data_type, offset = datatype.__unpack__(buffer, offset, data_type_dump)
+                    data_type_dump = dump.add_record(access="data_type", fmt=cls.data_type.fmt)
+                    m_data_type, offset = cls.data_type.fmt.__unpack__(buffer, offset, data_type_dump)
                     add_member(m_data_type)
 
                     data_dims_dump = dump.add_record(access="data_dims", fmt=cls.data_dims.fmt)
@@ -670,8 +670,8 @@ class TestTypeFactoryMultiDim(Case):
                     m_data, offset = data_fmt.__unpack__(buffer, offset, data_dump, dims=m_data_dims)
                     add_member(m_data)
 
-                    bookend_dump = dump.add_record(access="bookend", fmt=uint8)
-                    m_bookend, offset = uint8.__unpack__(buffer, offset, bookend_dump)
+                    bookend_dump = dump.add_record(access="bookend", fmt=cls.bookend.fmt)
+                    m_bookend, offset = cls.bookend.fmt.__unpack__(buffer, offset, bookend_dump)
                     add_member(m_bookend)
 
                 return structure, offset
