@@ -79,25 +79,25 @@ class TestNormal:
             structure = list.__new__(cls)
 
             if dump is None:
-                m_getable, offset = uint8.__unpack__(buffer, offset, dump)
+                m_getable, offset = cls.getable.fmt.__unpack__(buffer, offset, dump)
 
-                m_setable, offset = uint8.__unpack__(buffer, offset, dump)
+                m_setable, offset = cls.setable.fmt.__unpack__(buffer, offset, dump)
 
-                m_constant, offset = uint8.__unpack__(buffer, offset, dump)
-                if m_constant != 3:
-                    raise ValueError(f"'constant' must be {3}")
+                m_constant, offset = cls.constant.fmt.__unpack__(buffer, offset, dump)
+                if m_constant != cls.constant.default:
+                    raise ValueError(f"'constant' must be {cls.constant.default}")
 
             else:
-                getable_dump = dump.add_record(access="getable", fmt=uint8)
-                m_getable, offset = uint8.__unpack__(buffer, offset, getable_dump)
+                getable_dump = dump.add_record(access="getable", fmt=cls.getable.fmt)
+                m_getable, offset = cls.getable.fmt.__unpack__(buffer, offset, getable_dump)
 
-                setable_dump = dump.add_record(access="setable", fmt=uint8)
-                m_setable, offset = uint8.__unpack__(buffer, offset, setable_dump)
+                setable_dump = dump.add_record(access="setable", fmt=cls.setable.fmt)
+                m_setable, offset = cls.setable.fmt.__unpack__(buffer, offset, setable_dump)
 
-                constant_dump = dump.add_record(access="constant", fmt=uint8)
-                m_constant, offset = uint8.__unpack__(buffer, offset, constant_dump)
-                if m_constant != 3:
-                    raise ValueError(f"'constant' must be {3}")
+                constant_dump = dump.add_record(access="constant", fmt=cls.constant.fmt)
+                m_constant, offset = cls.constant.fmt.__unpack__(buffer, offset, constant_dump)
+                if m_constant != cls.constant.default:
+                    raise ValueError(f"'constant' must be {cls.constant.default}")
 
             structure[:] = (m_getable, m_setable, m_constant)
 
@@ -155,8 +155,8 @@ class TestBitField(TestNormal):
                 m_setable = (bitfields_0 >> 4) & 0xf
 
                 m_constant = (bitfields_0 >> 8) & 0xf
-                if m_constant != 3:
-                    raise ValueError(f"'constant' must be {3}")
+                if m_constant != cls.constant.default:
+                    raise ValueError(f"'constant' must be {cls.constant.default}")
 
             else:
                 bitfields_0_dump = dump.add_record()
@@ -170,8 +170,8 @@ class TestBitField(TestNormal):
 
                 m_constant = (bitfields_0 >> 8) & 0xf
                 dump.add_record(access="constant", bits=(8, 4), value=m_constant, fmt=int)
-                if m_constant != 3:
-                    raise ValueError(f"'constant' must be {3}")
+                if m_constant != cls.constant.default:
+                    raise ValueError(f"'constant' must be {cls.constant.default}")
 
             structure[:] = (m_getable, m_setable, m_constant)
 
