@@ -137,47 +137,47 @@ class TestSimple(Case):
                     if m_size is None:
                         pieces.append(b"")
                     else:
-                        uint8.__pack__(m_size, pieces, dump)
+                        cls.size.fmt.__pack__(m_size, pieces, dump)
 
                     if m_size is None:
                         string_pieces_index = len(pieces)
                         cls.string.fmt.__pack__(m_string, pieces, dump)
                         m_size = len(b"".join(pieces[string_pieces_index:]))
-                        uint8.__pack__(m_size, pieces, dump)
+                        cls.size.fmt.__pack__(m_size, pieces, dump)
                         pieces[size_pieces_index] = pieces.pop()
                     else:
                         cls.string.fmt.__pack__(m_string, pieces, dump)
 
-                    uint8.__pack__(m_bookend, pieces, dump)
+                    cls.bookend.fmt.__pack__(m_bookend, pieces, dump)
 
                 else:
-                    size_dump = dump.add_record(access="size", fmt=uint8)
+                    size_dump = dump.add_record(access="size", fmt=cls.size.fmt)
                     size_pieces_index = len(pieces)
                     if m_size is None:
                         size_dump.value = "<skipped>"
                         pieces.append(b"")
                     else:
-                        uint8.__pack__(m_size, pieces, size_dump)
+                        cls.size.fmt.__pack__(m_size, pieces, size_dump)
 
                     string_dump = dump.add_record(access="string", fmt=cls.string.fmt)
                     if m_size is None:
                         string_pieces_index = len(pieces)
                         cls.string.fmt.__pack__(m_string, pieces, string_dump)
                         m_size = len(b"".join(pieces[string_pieces_index:]))
-                        uint8.__pack__(m_size, pieces, size_dump)
+                        cls.size.fmt.__pack__(m_size, pieces, size_dump)
                         pieces[size_pieces_index] = pieces.pop()
                     else:
                         cls.string.fmt.__pack__(m_string, pieces, string_dump)
 
-                    bookend_dump = dump.add_record(access="bookend", fmt=uint8)
-                    uint8.__pack__(m_bookend, pieces, bookend_dump)
+                    bookend_dump = dump.add_record(access="bookend", fmt=cls.bookend.fmt)
+                    cls.bookend.fmt.__pack__(m_bookend, pieces, bookend_dump)
 
             @classmethod
             def __unpack__(cls, buffer: bytes, offset: int, dump: Optional[Record] = None) -> Tuple["Simple", int]:
                 structure = list.__new__(cls)
 
                 if dump is None:
-                    m_size, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_size, offset = cls.size.fmt.__unpack__(buffer, offset, dump)
 
                     buffer, string_buffer = buffer[:offset + m_size], buffer
                     if len(buffer) < offset + m_size:
@@ -187,11 +187,11 @@ class TestSimple(Case):
                         cls.string.report_extra_bytes(buffer[offset:])
                     buffer = string_buffer
 
-                    m_bookend, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_bookend, offset = cls.bookend.fmt.__unpack__(buffer, offset, dump)
 
                 else:
-                    size_dump = dump.add_record(access="size", fmt=uint8)
-                    m_size, offset = uint8.__unpack__(buffer, offset, size_dump)
+                    size_dump = dump.add_record(access="size", fmt=cls.size.fmt)
+                    m_size, offset = cls.size.fmt.__unpack__(buffer, offset, size_dump)
 
                     string_dump = dump.add_record(access="string", fmt=cls.string.fmt)
                     buffer, string_buffer = buffer[:offset + m_size], buffer
@@ -202,8 +202,8 @@ class TestSimple(Case):
                         cls.string.report_extra_bytes(buffer[offset:], string_dump)
                     buffer = string_buffer
 
-                    bookend_dump = dump.add_record(access="bookend", fmt=uint8)
-                    m_bookend, offset = uint8.__unpack__(buffer, offset, bookend_dump)
+                    bookend_dump = dump.add_record(access="bookend", fmt=cls.bookend.fmt)
+                    m_bookend, offset = cls.bookend.fmt.__unpack__(buffer, offset, bookend_dump)
 
                 structure[:] = (m_size, m_string, m_bookend)
 
@@ -470,47 +470,47 @@ class TestRatio(Case):
                     if m_size is None:
                         pieces.append(b"")
                     else:
-                        uint8.__pack__(m_size, pieces, dump)
+                        cls.size.fmt.__pack__(m_size, pieces, dump)
 
                     if m_size is None:
                         string_pieces_index = len(pieces)
                         cls.string.fmt.__pack__(m_string, pieces, dump)
                         m_size = int(len(b"".join(pieces[string_pieces_index:])) // 2)
-                        uint8.__pack__(m_size, pieces, dump)
+                        cls.size.fmt.__pack__(m_size, pieces, dump)
                         pieces[size_pieces_index] = pieces.pop()
                     else:
                         cls.string.fmt.__pack__(m_string, pieces, dump)
 
-                    uint8.__pack__(m_bookend, pieces, dump)
+                    cls.bookend.fmt.__pack__(m_bookend, pieces, dump)
 
                 else:
-                    size_dump = dump.add_record(access="size", fmt=uint8)
+                    size_dump = dump.add_record(access="size", fmt=cls.size.fmt)
                     size_pieces_index = len(pieces)
                     if m_size is None:
                         size_dump.value = "<skipped>"
                         pieces.append(b"")
                     else:
-                        uint8.__pack__(m_size, pieces, size_dump)
+                        cls.size.fmt.__pack__(m_size, pieces, size_dump)
 
                     string_dump = dump.add_record(access="string", fmt=cls.string.fmt)
                     if m_size is None:
                         string_pieces_index = len(pieces)
                         cls.string.fmt.__pack__(m_string, pieces, string_dump)
                         m_size = int(len(b"".join(pieces[string_pieces_index:])) // 2)
-                        uint8.__pack__(m_size, pieces, size_dump)
+                        cls.size.fmt.__pack__(m_size, pieces, size_dump)
                         pieces[size_pieces_index] = pieces.pop()
                     else:
                         cls.string.fmt.__pack__(m_string, pieces, string_dump)
 
-                    bookend_dump = dump.add_record(access="bookend", fmt=uint8)
-                    uint8.__pack__(m_bookend, pieces, bookend_dump)
+                    bookend_dump = dump.add_record(access="bookend", fmt=cls.bookend.fmt)
+                    cls.bookend.fmt.__pack__(m_bookend, pieces, bookend_dump)
 
             @classmethod
             def __unpack__(cls, buffer: bytes, offset: int, dump: Optional[Record] = None) -> Tuple["Ratio", int]:
                 structure = list.__new__(cls)
 
                 if dump is None:
-                    m_size, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_size, offset = cls.size.fmt.__unpack__(buffer, offset, dump)
 
                     string_nbytes = int(m_size * 2)
                     buffer, string_buffer = buffer[:offset + string_nbytes], buffer
@@ -521,11 +521,11 @@ class TestRatio(Case):
                         cls.string.report_extra_bytes(buffer[offset:])
                     buffer = string_buffer
 
-                    m_bookend, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_bookend, offset = cls.bookend.fmt.__unpack__(buffer, offset, dump)
 
                 else:
-                    size_dump = dump.add_record(access="size", fmt=uint8)
-                    m_size, offset = uint8.__unpack__(buffer, offset, size_dump)
+                    size_dump = dump.add_record(access="size", fmt=cls.size.fmt)
+                    m_size, offset = cls.size.fmt.__unpack__(buffer, offset, size_dump)
 
                     string_dump = dump.add_record(access="string", fmt=cls.string.fmt)
                     string_nbytes = int(m_size * 2)
@@ -537,8 +537,8 @@ class TestRatio(Case):
                         cls.string.report_extra_bytes(buffer[offset:], string_dump)
                     buffer = string_buffer
 
-                    bookend_dump = dump.add_record(access="bookend", fmt=uint8)
-                    m_bookend, offset = uint8.__unpack__(buffer, offset, bookend_dump)
+                    bookend_dump = dump.add_record(access="bookend", fmt=cls.bookend.fmt)
+                    m_bookend, offset = cls.bookend.fmt.__unpack__(buffer, offset, bookend_dump)
 
                 structure[:] = (m_size, m_string, m_bookend)
 
@@ -849,28 +849,28 @@ class TestNoCompute(Case):
                 (m_size, m_string, m_bookend) = value
 
                 if dump is None:
-                    uint8.__pack__(m_size, pieces, dump)
+                    cls.size.fmt.__pack__(m_size, pieces, dump)
 
                     cls.string.fmt.__pack__(m_string, pieces, dump)
 
-                    uint8.__pack__(m_bookend, pieces, dump)
+                    cls.bookend.fmt.__pack__(m_bookend, pieces, dump)
 
                 else:
-                    size_dump = dump.add_record(access="size", fmt=uint8)
-                    uint8.__pack__(m_size, pieces, size_dump)
+                    size_dump = dump.add_record(access="size", fmt=cls.size.fmt)
+                    cls.size.fmt.__pack__(m_size, pieces, size_dump)
 
                     string_dump = dump.add_record(access="string", fmt=cls.string.fmt)
                     cls.string.fmt.__pack__(m_string, pieces, string_dump)
 
-                    bookend_dump = dump.add_record(access="bookend", fmt=uint8)
-                    uint8.__pack__(m_bookend, pieces, bookend_dump)
+                    bookend_dump = dump.add_record(access="bookend", fmt=cls.bookend.fmt)
+                    cls.bookend.fmt.__pack__(m_bookend, pieces, bookend_dump)
 
             @classmethod
             def __unpack__(cls, buffer: bytes, offset: int, dump: Optional[Record] = None) -> Tuple["Struct", int]:
                 structure = list.__new__(cls)
 
                 if dump is None:
-                    m_size, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_size, offset = cls.size.fmt.__unpack__(buffer, offset, dump)
 
                     buffer, string_buffer = buffer[:offset + m_size], buffer
                     if len(buffer) < offset + m_size:
@@ -880,11 +880,11 @@ class TestNoCompute(Case):
                         cls.string.report_extra_bytes(buffer[offset:])
                     buffer = string_buffer
 
-                    m_bookend, offset = uint8.__unpack__(buffer, offset, dump)
+                    m_bookend, offset = cls.bookend.fmt.__unpack__(buffer, offset, dump)
 
                 else:
-                    size_dump = dump.add_record(access="size", fmt=uint8)
-                    m_size, offset = uint8.__unpack__(buffer, offset, size_dump)
+                    size_dump = dump.add_record(access="size", fmt=cls.size.fmt)
+                    m_size, offset = cls.size.fmt.__unpack__(buffer, offset, size_dump)
 
                     string_dump = dump.add_record(access="string", fmt=cls.string.fmt)
                     buffer, string_buffer = buffer[:offset + m_size], buffer
@@ -895,8 +895,8 @@ class TestNoCompute(Case):
                         cls.string.report_extra_bytes(buffer[offset:], string_dump)
                     buffer = string_buffer
 
-                    bookend_dump = dump.add_record(access="bookend", fmt=uint8)
-                    m_bookend, offset = uint8.__unpack__(buffer, offset, bookend_dump)
+                    bookend_dump = dump.add_record(access="bookend", fmt=cls.bookend.fmt)
+                    m_bookend, offset = cls.bookend.fmt.__unpack__(buffer, offset, bookend_dump)
 
                 structure[:] = (m_size, m_string, m_bookend)
 
